@@ -10,6 +10,7 @@ python immutable.py
 python mutable.py
 python copies.py
 python copy_method.py
+python name_rebinding.py
 
 # call stack
 python add_one.py
@@ -24,6 +25,7 @@ python bin_tree.py
 python hash_set.py
 
 # configuration
+python not_node_types.py
 python highlight.py
 
 # extensions
@@ -32,3 +34,5 @@ python extension_pandas.py
 
 # introspection
 python avltree.py
+python bin_search.py
+python introspect_depth.py
