@@ -1,15 +1,12 @@
 # This file is part of memory_graph.
 # Copyright (c) 2023, Bas Terwijn.
 # SPDX-License-Identifier: BSD-2-Clause
-
 import memory_graph as mg
 
-image = 1
 
 def get_subsets(subsets, data, i, subset):
     global image
-    mg.render(mg.get_call_stack(), f"power_set{image}.png")
-    image += 1
+    mg.render(mg.stack(), 'power_set.png', numbered=True)
     if i == len(data):
         subsets.append(subset.copy())
         return
@@ -17,12 +14,13 @@ def get_subsets(subsets, data, i, subset):
     get_subsets(subsets, data, i+1, subset) #    do include data[i]
     subset.pop()
     get_subsets(subsets, data, i+1, subset) # don't include data[i]
-    mg.render(mg.get_call_stack(), f"power_set{image}.png")
-    image += 1
+    mg.render(mg.stack(), 'power_set.png', numbered=True)
 
 def power_set(data):
     subsets = []
+    mg.render(mg.stack(), 'power_set.png', numbered=True)
     get_subsets(subsets, data, 0, [])
+    mg.render(mg.stack(), 'power_set.png', numbered=True)
     return subsets
 
 print( power_set(['a', 'b', 'c']) )
